==> aws-cdk.aws-lambda-go-alpha-2.17.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_lambda_go_alpha_ICommandHooks(p) {
}
function _aws_cdk_aws_lambda_go_alpha_GoFunction(p) {
}
function _aws_cdk_aws_lambda_go_alpha_GoFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_go_alpha_BundlingOptions(p.bundling);
    if (!visitedObjects.has(p.events))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_ILayerVersion(p.layers);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_go_alpha_BundlingOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.commandHooks))
        _aws_cdk_aws_lambda_go_alpha_ICommandHooks(p.commandHooks);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_go_alpha_ICommandHooks, _aws_cdk_aws_lambda_go_alpha_GoFunction, _aws_cdk_aws_lambda_go_alpha_GoFunctionProps, _aws_cdk_aws_lambda_go_alpha_BundlingOptions };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-lambda-go-alpha-2.19.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_lambda_go_alpha_ICommandHooks(p) {
}
function _aws_cdk_aws_lambda_go_alpha_GoFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.bundling))
        _aws_cdk_aws_lambda_go_alpha_BundlingOptions(p.bundling);
    if (!visitedObjects.has(p.events))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_lambda_ILayerVersion(p.layers);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_lambda_go_alpha_GoFunction(p) {
}
function _aws_cdk_aws_lambda_go_alpha_BundlingOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.commandHooks))
        _aws_cdk_aws_lambda_go_alpha_ICommandHooks(p.commandHooks);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_go_alpha_ICommandHooks, _aws_cdk_aws_lambda_go_alpha_GoFunctionProps, _aws_cdk_aws_lambda_go_alpha_GoFunction, _aws_cdk_aws_lambda_go_alpha_BundlingOptions };
module.exports.DeprecationError = DeprecationError;
